#
# spec file for package oce
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

# Whether clang should be used instead of gcc
%bcond_with scanbuild
%if %{with scanbuild}
%bcond_without clang
%else
%bcond_with clang
%endif

# Whether DRAWEXE should be built
%bcond_without build_draw

# Disable VTK on < 13.2
%if 0%{?suse_version} < 1320
%bcond_with build_vtk
%else
%bcond_without build_vtk
%endif

# Define openCASCADE version
%define ocversion 6.8.0

Name:           oce
Version:        0.17.99+git20160303.1317
Release:        1.1
Summary:        OpenCASCADE Community Edition

Group:          Productivity/Graphics/CAD
License:        LGPL-2.1-with-Open-CASCADE-exception
URL:            https://github.com/tpaviot/oce
Source0:        oce.tar.xz
Source1:        oce-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
 
BuildRequires:  cmake
BuildRequires:  fdupes
%if %{with clang}
BuildRequires:  llvm-clang
BuildRequires:  libstdc++-devel
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  ftgl-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(python)
%if %{with build_draw}
%if 0%{?suse_version} > 1230
BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(tk)
%else
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
%endif
%endif
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  xz
%if %{with build_vtk}
BuildRequires:  vtk-devel
BuildRequires:  netcdf-devel
BuildRequires:  libnetcdf_c++-devel
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xt)
%ifarch x86_64
BuildRequires:  -libjawt.so()(64bit)
BuildRequires:  -libjawt.so(SUNWprivate_1.1)(64bit)
%else
%if 0%{?suse_version} > 1310
BuildRequires:  -libjawt.so
%else
BuildRequires:  -libjawt.so()
%endif
BuildRequires:  -libjawt.so(SUNWprivate_1.1)
%endif
%endif

Provides:       OpenCASCADE = %{ocversion}
Provides:       OCE = %{version}
Obsoletes:      OpenCASCADE < %{ocversion}
Obsoletes:      OCE < %{version}
Conflicts:      otherproviders(OpenCASCADE)

 
%description
OpenCASCADE is a suite for 3D surface and solid modeling, visualization, data
exchange and rapid application development. It is an excellent platform for
development of numerical simulation software including CAD/CAM/CAE, AEC and
GIS, as well as PDM applications.

%if %{with build_vtk}
%package vtk
Summary:        VTK libraries

%description vtk
This package includes OpenCASCADE VTK libraries.
%endif

%if %{with build_draw}
%package DRAWEXE
Summary:        Scripting interface to the OpenCASCADE libraries
Group:          Productivity/Graphics/Visualization/Other

%description DRAWEXE
This program provides a kind of scripting interface to the OpenCASCADE
libraries. You can perform a simple test by starting it and entering at the
command line: "pload ALL" then "source /usr/share/oce/src/DrawResources/VisualizationDemo.tcl".
%endif

%package devel
Summary:        Development files for openCASCADE
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
%if %{with build_vtk}
Requires:       %{name}-vtk = %{version}
%endif
Provides:       OpenCASCADE-devel = %{ocversion}
Provides:       OCE-devel = %{version}
Obsoletes:      OpenCASCADE-devel < %{ocversion}
Obsoletes:      OCE-devel < %{version}
Conflicts:      otherproviders(OpenCASCADE-devel)

%description devel
This package contains the files needed for development with OpenCASCADE.

%prep
%setup -q -n %{name}

%build
mkdir build
cd build
  CFLAGS=$RPM_OPT_FLAGS \
  CXXFLAGS=$RPM_OPT_FLAGS \
%if %{with clang}
%if %{with scanbuild}
  CC=/usr/share/clang/scan-build/ccc-analyzer CXX=/usr/share/clang/scan-build/c++-analyzer CCC_CXX=clang++ \
%else
  CC=clang CXX=clang++ \
%endif
%endif
  cmake \
    -DOCE_USE_BUNDLE=OFF -DOCE_BUNDLE_AUTOINSTALL=OFF \
    -DOCE_USE_PCH=OFF \
    -DOCE_BUILD_SHARED_LIB=ON \
    -DOCE_DISABLE_X11=OFF \
    -DOCE_MODEL=ON \
    -DOCE_OCAF=ON \
    -DOCE_DATAEXCHANGE=ON \
%if %{with build_vtk}
    -DOCE_WITH_VTK=ON \
%else
    -DOCE_WITH_VTK=OFF \
%endif
%if %{with build_draw}
    -DOCE_DRAW=ON \
%else
    -DOCE_DRAW=OFF \
%endif
    -DOCE_VISUALISATION=ON -DOCE_DISABLE_TKSERVICE_FONT=OFF \
    -DOCE_WITH_GL2PS=ON \
    -DOCE_WITH_FREEIMAGE=ON \
    -DOCE_EXTRA_WARNINGS=OFF \
    -DOCE_TESTING=OFF \
    -DOCE_ADD_HEADERS=OFF \
    -DOCE_RPATH_FILTER_SYSTEM_PATHS=ON \
    -DOCE_ENABLE_DEB_FLAG=ON \
    -DOCE_COVERAGE=OFF \
    -DOCE_MULTITHREAD_LIBRARY=OPENMP -DOCE_TBB_MALLOC_SUPPORT=OFF \
    -DOCE_INSTALL_PREFIX=%_prefix \
    -DOCE_INSTALL_BIN_DIR=%_bindir \
    -DOCE_INSTALL_LIB_DIR=%_libdir/oce \
    -DOCE_INSTALL_PACKAGE_LIB_DIR=%_libdir/oce \
    -DOCE_INSTALL_INCLUDE_DIR=%_includedir/oce \
    -DOCE_INSTALL_DATA_DIR=%_datadir/oce \
    -DOCE_INSTALL_CMAKE_DATA_DIR=%_datadir/cmake/Modules \
    ..
%if %{with scanbuild}
  /usr/share/clang/scan-build/scan-build --use-analyzer %_bindir/clang -analyze-headers \
%endif
  make %{?jobs:-j%jobs}
cd ..

%install
cd build
  make install DESTDIR=%buildroot
cd ..

%fdupes -s %buildroot/%_includedir

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%_libdir/oce
%if %{with build_vtk}
%exclude %_libdir/oce/*Vtk*.so.*
%endif
%exclude %_libdir/oce/*.so
%_datadir/oce
%if %{with build_draw}
%exclude %_datadir/oce/src/DrawResources

%files DRAWEXE
%defattr(-,root,root,-)
%_bindir/DRAWEXE
%_datadir/oce/src/DrawResources
%endif

%if %{with build_vtk}
%files vtk
%defattr(-,root,root,-)
%_libdir/oce/*Vtk*.so.*
%endif

%files devel
%defattr(-,root,root,-)
%_includedir/oce
%_libdir/oce/*.so
%_datadir/cmake/Modules/*.cmake

%changelog
* Sat Nov 30 2013 johannesobermayr@gmx.de
- initial package
- replacement for OpenCASCADE
